function CoQ = cospec(c, d, wintype, detrend, npad)
% function CoQ = cospec(c, d, wintype, detrend, npad)
% Real part is the coherence, imaginary part the quadrature, spectrum.

if nargin < 2,
   wintype = 'welch';
end;
if nargin < 3
   detrend = 1;
end
if nargin < 4
   npad = nan;
end

n = length(c);
if length(d) ~= n
   disp('cospec: series must be same length');
   Co = nan; Q = nan;
   return
end

if detrend
   c = c - c(1) - (c(n) - c(1)) * [0:(n-1)]' / (n-1);
   c = c - mean(c);
   d = d - d(1) - (d(n) - d(1)) * [0:(n-1)]' / (n-1);
   d = d - mean(d);
end

switch lower(wintype)
   case {'none'}
      win = ones(n,1);
   case {'bartlett'}
      win = 1.0 - abs( ([0:(n-1)]' - 0.5*n )/(0.5*n) );
   case {'welch'}
      win = 1.0 - ( ([0:(n-1)]' - 0.5*n )/(0.5*n) ).^2;
   case {'hann'}
      win = 0.5*( 1.0 - cos(2*pi*[0:(n-1)]'/n) );
   case {'bell'}
      win = ones(n,1); n4 = floor(n/4);
      win(1:n4) = 0.5*(1 - cos(([1:n4]'-1)*pi/n4));
      win(n-n4+1:n) = win(n4:-1:1);
   otherwise
      win = nan + zeros(n,1);
      disp('Unknown window');
end
wssi = 1.0 / (n*sum(win.^2));
c = c.*win;
d = d.*win;

if ~isnan(npad) & n < npad
   c = [ c ; zeros(npad-n,1) ];
   d = [ d ; zeros(npad-n,1) ];
end

fc = fft(c);
fd = fft(d);
fcd = fc .* conj(fd);

n2 = ceil(length(fc)/2) + 1;

CoQ = wssi * fcd(1:n2);



