function [ tclon, tclat, utc, vtc ] = hewspline(sptime,splon,splat,time)
% matlab version of H. Willoughby's spline interpolation code
% Inputs sptime, splat, splon Spline points for interpolation
%        time  Output times
% Outputs tclon tclat  Interpolated positions
%        utc, vtc      Motion

ispln = length(splat)-0;
nn = length(splon);

%     Calculates track by splines in interval and by
%     extrapolation outside interval.
%     Inputs are TM, TBGN, TEND, DT, ISPLN, splat(20) and splon(20).
%     Outputs are tclat, tclon, utc and vtc.
%     tclat, tclon: storm lat. and long., in degrees, at time TM
%     utc, vtc: speeds in meters/sec, relative to equator and true
%       north, respectively.

dim = 1.112e+05/86400.0;
tbgn = sptime(2);
tend = sptime(nn-1);
dt = sptime(2) - sptime(1);

splat = splat/1.5; splon = splon/1.5;   % hew's curious unit conversion

tclon = repmat(nan, size(time));
tclat = repmat(nan, size(time));
utc   = repmat(nan, size(time));
vtc   = repmat(nan, size(time));

ix = find( time >= tbgn & time <= tend );

% if (( time < tbgn ) | ( time > tend ))
%    disp('hewspline time out of range');
%    tclon = nan;
%    tclat = nan;
%    utc = nan;
%    vtc = nan;
   % TNEW = TBGN
   % IF( TM .LT. TEND )GO TO 49
   % TNEW = TEND
   %    49 CONTINUE
   % C  GETS POS AND SPD AT BEGIN OR END TIME
   % CALL POLY1( TNEW, TBGN, TEND, DT, ISPLN, tclat, DLT, D2LT, splat )
   % CALL POLY1( TNEW, TBGN, TEND, DT, ISPLN, tclon, DLO, D2LO, splon )
   % C  EXTRAPOLATES
   % tclat = tclat + DLT * ( TM - TNEW )
   % tclon = tclon + DLO * ( TM - TNEW )
% else
   [ tclat(ix), dlt, d2lt ] = poly1(time(ix), tbgn, tend, dt, ispln, splat);
   [ tclon(ix), dlo, d2lo ] = poly1(time(ix), tbgn, tend, dt, ispln, splon);
   dims = dim * cos( tclat(ix) / 57.296 );
%  Convert speeds to m/s:
   utc(ix) = dims .* dlo;
   vtc(ix) = dim * dlt;
% end

% *********1*********2*********3*********4*********5*********6*********7**

function [ blt, dlt, d2lt ] = poly1(tt, tbgn, tend, dt, ispln, alt);
%
%     Evaluates spline function and first 2 derivatives:
%

blt = 0;
dlt = 0;
d2lt = 0;
for ll = 1 : ispln
   [splf, d, d2] =  splf1( tt, ll, tbgn, tend, dt );
   blt = blt + alt( ll ) * splf;
   dlt = dlt + alt( ll ) * d;
   d2lt = d2lt + alt( ll ) * d2;
end 

% *********1*********2*********3*********4*********5*********6*********7**
function [y, dy, dy2] = splf1(x, n, xmin, xmax, dx)
%     Inputs: x, n, xmin, xmax, dx
%     Outputs: y, dy, dy2
% Seems to be an implementation of equation A1 of Ooyama (1987) plus derivatives

y = zeros(size(x));;
dy = zeros(size(x));
dy2 = zeros(size(x));

xm = xmin + dx * ( n - 2 );   % The current node
xx = abs(( x - xm ) / dx );   % eq A3
ss = sign( x - xm );

ix = find( x >= xmin & x <= xmax & xx <= 1 );
y(ix)   =   0.25*(2 - xx(ix)).^3 -   (1 - xx(ix)).^3;
dy(ix)  = (-0.75*(2 - xx(ix)).^2 + 3*(1 - xx(ix)).^2).*ss(ix)/dx;
d2y(ix) = ( 1.50*(2 - xx(ix))    - 6*(1 - xx(ix))   )/dx^2;

ix = find( x >= xmin & x <= xmax & xx >= 1 & xx <= 2 );
y(ix)   =  0.25*(2 - xx(ix)).^3;
dy(ix)  = -0.75*(2 - xx(ix)).^2.*ss(ix)/dx;
d2y(ix) =  1.50*(2 - xx(ix))   /dx^2;

