function [p,v] = holland_pv2(beta,r)
% function p = holland_p(beta,r)
% Holland 2-piece parametric pressure profile
% beta = [ b1 b2 rm pc pe ]

b1 = beta(1);
b2 = beta(2);
rm = beta(3);
pc = beta(4);
pe = beta(5);
ixin = find(r <= rm);
ixout = find(r > rm);
rmrbin = (rm./r(ixin)).^b1;
rmrbout = (rm./r(ixout)).^b2;

dp = pe - pc;
p = zeros(size(r));
p(ixin) = pc + dp*exp(-rmrbin);
p(ixout) = pc + dp*exp(-rmrbout);

p(find(isnan(r))) = nan;
