function [p,dp] = holland_p_xy(xy,beta)
% function [p,dp] = holland_p_xy(xy,beta)
% Holland parametric pressure profile in cartesian coordinates
% beta = [ vm rm b pc Tbar dx dy ], last two are optional

vm = beta(1);
rm = beta(2);
b  = beta(3);
pc = beta(4);
if length(beta) > 5
   dx = beta(6); dy = beta(7);
else
   dx = 0; dy = 0;
end

x = xy(:,1); y = xy(:,2);

r = hypot(x-dx, y-dy);
nr = length(r);
[p,dpr] = holland_p(r, beta(1:5));

if nargout >= 2
   dp = zeros(nr,7);
   dp(:,1:5) = dpr(:,1:5);
   dp(:,6) = dpr(:,6) .* (dx - x)./r;
   dp(:,7) = dpr(:,6) .* (dy - y)./r;
end


