function [p,dp] = holland_p_xyuv(xyt,beta,f)
% function [p,dp] = holland_p_xy(xyt,beta,f)
% Holland parametric pressure profile in cartesian coordinates
% xyt = [ x y t ] are space and time coordinates of observations
% beta = [ vm rm b pc Tbar dx dy ut vt ], last four are optional
% Environment geostrophic wind assumed to equal storm translation

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_v_xy f undefined')
      p = []; dp = [];
      return
   end
end;

vm = beta(1);
rm = beta(2);
b  = beta(3);
pc = beta(4);
if length(beta) > 5, dx = beta(6); dy = beta(7);
else                 dx = 0;       dy = 0;
end
if length(beta) > 7, ut = beta(8); vt = beta(9);
else                 ut = 0;       vt = 0;
end

x = xyt(:,1); y = xyt(:,2); t = xyt(:,3);

r = hypot(x-dx-ut*t, y-dy-vt*t);
nr = length(r);
[p,dpr] = holland_p(r, beta(1:5));

if nargout >= 2
   dp = zeros(nr,10);
   % Derivatives with respect to vm, rm, b, pc, Tbar
   dp(:,1:5) = dpr(:,1:5);
   % Derivatives with respect to dx, dy, ut, vt
   dp(:,6) = -dpr(:,6) .* (x - dx - ut*t)./r;
   dp(:,7) = -dpr(:,6) .* (y - dy - vt*t)./r;
   dp(:,8) = t .* dp(:,6);
   dp(:,9) = t .* dp(:,7);
   dp(:,10) = dpr(:,6);
end


