function [p,dp] = holland_p_xyuva(xyt,beta)
% function [p,dp] = holland_p_xy(xyt,beta)
% Holland parametric pressure profile in cartesian coordinates
% xyt = [ x y t ] are space and time coordinates of observations
% beta = [ vm rm b pc Tbar dx dy ut vt ax ay ], last six are optional

vm = beta(1);
rm = beta(2);
b  = beta(3);
pc = beta(4);
if length(beta) > 5, dx = beta(6); dy = beta(7); % displacement
else                 dx = 0;       dy = 0;
end
if length(beta) > 7, ut = beta(8); vt = beta(9); % velocity
else                 ut = 0;       vt = 0;
end
if length(beta) > 9, ax = beta(10); ay = beta(11); % acceleration
else                 ax = 0;        ay = 0;
end

x = xyt(:,1); y = xyt(:,2); t = xyt(:,3);

r = hypot(x-dx-ut*t-0.5*ax*t.^2, y-dy-vt*t-0.5*ay*t.^2);
nr = length(r);
[p,dpr] = holland_p(r, beta(1:5));

if nargout >= 2
   dp = zeros(nr,9);
   % Derivatives with respect to vm, rm, b, pc, Tbar
   dp(:,1:5) = dpr(:,1:5);
   % Derivatives with respect to dx, dy, ut, vt, ax, ay
   dp(:,6) = -dpr(:,6) .* (x - dx - ut*t - 0.5*ax*t.^2)./r;
   dp(:,7) = -dpr(:,6) .* (y - dy - vt*t - 0.5*ay*t.^2)./r;
   dp(:,8) = t .* dp(:,6);
   dp(:,9) = t .* dp(:,7);
   dp(:,10) = 0.5*t.^2 .* dp(:,6);
   dp(:,11) = 0.5*t.^2 .* dp(:,7);
end


