function [p,v] = holland_pv2(beta,r,f)
% function [p,v] = holland_pv2(beta,r[,f])
% Blended Holland 2-piece parametric pressure profile
% beta = [ b1 b2 rm pc pe ]

if (nargin <= 2)
   global f0;
   f = f0;
end

b1 = beta(1);
b2 = beta(2);
rm = beta(3);
pc = beta(4);
pe = beta(5);
dp = pe - pc;

rmrb1 = (rm./r).^b1;
rmrb2 = (rm./r).^b2;

p1 = pc + dp*exp(-rmrb1);
p2 = pc + dp*exp(-rmrb2);
dpdr1 = b1 * dp * exp(-rmrb1) .* rmrb1 ./ r;
dpdr2 = b2 * dp * exp(-rmrb2) .* rmrb2 ./ r;

rs = 8*(r/rm - 1);
%w = zeros(size(r)); dwdr = w;
%w( find( rs > 1 ) ) = 1;
%ix = find( abs(rs) <= 1 );
%w(ix) = 0.5 - 0.25*rs(ix).*(rs(ix).^2 - 3);
%dwdr(ix) = -1.5*(rs(ix).^2 - 1)/rm;
%w(ix) = 0.5 + rs(ix).*(3*rs(ix).^4 - 10*rs(ix).^2 + 15)/16;
%dwdr(ix) = (rs(ix).^2 -1).^2 * 15 / (8*rm);
w = 0.5 + atan(rs)/pi;
dwdr = 8 ./ (pi*rm*(1 + rs.^2));

p = (1-w).*p1 + w.*p2;
dpdr = dpdr1 + w.*(-dpdr1 + dpdr2) + dwdr.*(-p1 + p2);
rho = p/(287*298);

v = sqrt( r.*dpdr./rho + (0.5*f*r).^2 ) - 0.5*f*r;
%v=dwdr;
p(find(isnan(r))) = nan;
v(find(isnan(r))) = nan;
