function [p,v] = holland_pv3(beta,r,f)
% function [p,v] = holland_pv2(beta,r[,f])
% v-blended Holland 2-piece parametric pressure profile
% beta = [ b1 b2 vm rm pc ]

if (nargin <= 2)
   global f0;
   f = f0;
end

vm = beta(1);
rm = beta(2);
b1 = beta(3);
b2 = beta(4);
pc = beta(5);
Tv = 298; rhoc = pc/(287*Tv);
dp1 = vm^2*rhoc*2.71828/b1;
dp2 = vm^2*rhoc*2.71828/b2;

rmrb1 = (rm./r).^b1;
rmrb2 = (rm./r).^b2;

p1 = pc + dp1*exp(-rmrb1);
p2 = pc + dp2*exp(-rmrb2);
rho1 = p1/(287*Tv);
rho2 = p2/(287*Tv);
v1 = sqrt( b1*dp1./rho1 .* exp(-rmrb1) .* rmrb1 + (0.5*f*r).^2 ) - 0.5*f*r;
v2 = sqrt( b2*dp2./rho2 .* exp(-rmrb2) .* rmrb2 + (0.5*f*r).^2 ) - 0.5*f*r;

rs = 8*(r/rm - 1);
w = 0.5 + atan(rs)/pi;

v = (1-w).*v1 + w.*v2;

drdum = 1e3;
rdum = drdum : drdum : (max(r)+drdum);
rmrb1 = (rm./rdum).^b1;
rmrb2 = (rm./rdum).^b2;
p1 = pc + dp1*exp(-rmrb1);
p2 = pc + dp2*exp(-rmrb2);
rho1 = p1*100/(287*Tv);
rho2 = p2*100/(287*Tv);
v1 = sqrt( b1*dp1*100./rho1 .* exp(-rmrb1) .* rmrb1 + (0.5*f*rdum).^2 ) ...
   - 0.5*f*rdum;
v2 = sqrt( b2*dp2*100./rho2 .* exp(-rmrb2) .* rmrb2 + (0.5*f*rdum).^2 ) ...
    - 0.5*f*rdum;
rs = 8*(rdum/rm - 1);
w = 0.5 + atan(rs)/pi;
vdum = (1-w).*v1 + w.*v2;
gwe = vdum.^2 ./ rdum + f*vdum;
pdum = pc * exp( cumint(gwe, drdum) / (287*Tv) );
p = interp1( rdum,pdum,r );

p(find(isnan(r))) = nan;
v(find(isnan(r))) = nan;
