function [v,dv] = holland_v_xy(xy,beta,f)
% function [v,dv] = holland_v_xy(xy,beta,f)
% Holland parametric wind profile in cartesian coordinates
% beta = [ vm rm b pc Tbar dx dy ], last two are optional

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_v_xy f undefined')
      v = []; dv = [];
      return
   end
end;

if length(beta) > 5
   dx = beta(6); dy = beta(7);
else
   dx = 0; dy = 0;
end

x = xy(:,1); y = xy(:,2);

r = hypot(x-dx, y-dy);
nr = length(r);

[v,dvr] = holland_v(r,beta,f);

if nargout >= 2
   dv = zeros(nr,7);
   dv(:,1:5) = dvr(:,1:5);
   dv(:,6) = dvr(:,6) .* (dx - x)./r;
   dv(:,7) = dvr(:,6) .* (dy - y)./r;
end

