function [v,dv] = holland_vz(r,beta,f)
% function [v,dv] = holland_vz(r,beta,f)
% For height coordinates

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_vz f undefined')
      v = []; dv = [];
      return
   end
end;

vm = beta(1);
rm = beta(2);
b  = beta(3);
% zc = beta(4);
RT = 287*beta(5);
ee = exp(1.0);
nr = length(r);
rmrb = (rm./r).^b;
e1rmrb = exp(1.0 - rmrb);
sq = sqrt( vm^2 * e1rmrb .* rmrb + (0.5*f*r).^2 );  

v = sq - 0.5*f*r;
v(find(isnan(r))) = nan;
v(find(r<0)) = 0;

if nargout >= 2
   dv = zeros(nr,6);
   dv(:,1) = vm * e1rmrb .* rmrb ./ sq;
   dv(:,2) = b*vm^2/(2*rm) * e1rmrb .* rmrb .* (1 - rmrb) ./ sq;
   dv(:,3) = 0.5*vm^2 * e1rmrb .* rmrb .* (1 - rmrb) .* log(rm./r) ./ sq;
   dv(:,4) = 0;
   dv(:,5) = 0;
   dv(:,6) = -0.5*f + ( (0.5*f*r).^2 - 0.5*b*vm^2*e1rmrb.*rmrb.*(1 - rmrb) ) ./ (r.*sq);
end
   
ix = find(r == -999.0);
if ~isempty(ix) 
   % Special point, put in penalty term on length scales etc.
   rmhat = 25e3; rmscal = 1;
   bhat = 1.5; bscal = 1;
   v(ix) = rmscal*(rm/rmhat - 1)^4 + bscal*(b/bhat - 1)^4;
   if nargout >= 2
      dv(ix,1) = 0;
      dv(ix,2) = 4*rmscal/rmhat*(rm/rmhat - 1)^3;
      dv(ix,3) = 4*bscal/bhat*(b/bhat - 1)^3;
      dv(ix,4) = 0;
      dv(ix,5) = 0;
      dv(ix,6) = nan;
   end
end
