function [v,dv] = holland_vz_xyuv(xyt,beta,f)
% function [v,dv] = holland_vz_xyuv(xyt,beta,f)
% Holland parametric wind profile in cartesian-height coordinates
% beta = [ vm rm b zc Tbar dx dy ut vt ], last four are optional

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_v_xy f undefined')
      v = []; dv = [];
      return
   end
end;

if length(beta) > 5, dx = beta(6); dy = beta(7);
else                 dx = 0; dy = 0;
end
if length(beta) > 7, ut = beta(8); vt = beta(9);
else                 ut = 0;       vt = 0;
end

x = xyt(:,1); y = xyt(:,2); t = xyt(:,3);

r = hypot(x - dx - ut*t, y - dy - vt*t);
nr = length(r);

[v,dvr] = holland_vz(r,beta,f);

if nargout >= 2
   dv = zeros(nr,9);
   dv(:,1:5) = dvr(:,1:5);
   dv(:,6) = dvr(:,6) .* (dx - x)./r;
   dv(:,7) = dvr(:,6) .* (dy - y)./r;
   dv(:,8) = t .* dv(:,6);
   dv(:,9) = t .* dv(:,7);
end

