function [z,dz] = holland_z(r,beta)
% function [z,dz] = holland_z(r,beta)
% Holland parametric height profile
% beta = [ vm rm b zc Tbar ]
% dz(:,1:5) is the derivatives of z with respect to beta 
% dz(:,6) is the derivative of z with respect to r

g = 9.80665;

vm = beta(1);
rm = beta(2);
b  = beta(3);
zc = beta(4);
RT = 287*beta(5);

nr = length(r);
z = zeros(nr,1);
if nargout >= 2
   dz = zeros(nr,6);
end

ix = find(r > 0.0);
if ~isempty(ix)
   rmrb = (rm./r(ix)).^b;
   e1rmrb = exp(1.0 - rmrb);
   z(ix) = zc + (vm^2 / (b*g)) * e1rmrb;
   if nargout >= 2
      dz(ix,1) = (2*vm/(b*g)) * e1rmrb;
      dz(ix,2) = (-vm^2/(rm*g)) * e1rmrb .* rmrb;
      dz(ix,3) = (-vm^2/(b^2*g)) * e1rmrb .* (1 + b*rmrb.*log(rm./r(ix)));
      dz(ix,4) = 1;
      dz(ix,5) = nan;
      dz(ix,6) = (vm^2/g) .* e1rmrb .* rmrb ./ r(ix);
   end
end

ix = find(r == 0.0);
if ~isempty(ix)
   z(ix) = zc;
   if nargout >= 2
      dz(ix,1) = 0.0;
      dz(ix,2) = 0.0;
      dz(ix,3) = 0.0;
      dz(ix,4) = 1.0;
      dz(ix,5) = nan;
      dz(ix,6) = 0.0;
   end
end

ix = find(r == -999.0);
if ~isempty(ix) 
   disp('CAUTION holland_z PENALTY POINT USED');
   pause
   % Special point, put in penalty term on length scales etc.
   rmhat = 25e3; rmscal = 1;
   bhat = 1.5; bscal = 1;
   z(ix) = rmscal*(rm/rmhat - 1)^4 + bscal*(b/bhat - 1)^4;
   if nargout >= 2
      dz(ix,1) = 0;
      dz(ix,2) = 4*rmscal/rmhat*(rm/rmhat - 1)^3;
      dz(ix,3) = 4*bscal/bhat*(b/bhat - 1)^3;
      dz(ix,4) = 0;
      dz(ix,5) = nan;
      dz(ix,6) = nan;
   end
end

