function [z,dz] = holland_z_xyuv(xyt,beta,f)
% function [z,dz] = holland_z_xy(xyt,beta,f)
% Holland parametric height profile in cartesian coordinates
% xyt = [ x y t ] are space and time coordinates of observations
% beta = [ vm rm b zc Tbar dx dy ut vt ], last four are optional
% Environment geostrophic wind assumed to equal storm translation

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_z_xyuv f undefined')
      z = []; dz = [];
      return
   end
end;

g = 9.80665;

vm = beta(1);
rm = beta(2);
b  = beta(3);
zc = beta(4);
if length(beta) > 5, dx = beta(6); dy = beta(7);
else                 dx = 0;       dy = 0;
end
if length(beta) > 7, ut = beta(8); vt = beta(9);
else                 ut = 0;       vt = 0;
end

% Environmental height gradient
zxenv = (f/g)*vt; zyenv = -(f/g)*ut;

x = xyt(:,1); y = xyt(:,2); t = xyt(:,3);

r = hypot(x-dx-ut*t, y-dy-vt*t);
nr = length(r);
[z,dzr] = holland_z(r, beta(1:5));

z = z + zxenv*x + zyenv*y;

if nargout >= 2
   dz = zeros(nr,9);
   % Derivatives with respect to vm, rm, b, zc, Tbar
   dz(:,1:5) = dzr(:,1:5);
   % Derivatives with respect to dx, dy, ut, vt
   dz(:,6) = -dzr(:,6) .* (x - dx - ut*t)./r;
   dz(:,7) = -dzr(:,6) .* (y - dy - vt*t)./r;
   dz(:,8) = t .* dz(:,6);
   dz(:,9) = t .* dz(:,7);
end


