function [z,dz] = holland_z_xyuvt(xyt,beta,f)
% function [z,dz] = holland_z_xyt(xyt,beta,f)
% Holland parametric height profile in cartesian coordinates
% xyt = [ x y t ] are space and time coordinates of observations
% beta = [ vm rm b zc Tbar dvm2dt dx dy ut vt ], last four are optional
% Environment geostrophic wind assumed to equal storm translation

if (nargin <= 2), 
   global f0;
   if ~isempty(f0)
      f = f0; 
   else
      disp('Error: holland_z_xyuvt f undefined')
      z = []; dz = [];
      return
   end
end;

g = 9.80665;

if length(beta) > 6, dx = beta(7); dy = beta(8);
else                 dx = 0;       dy = 0;
end
if length(beta) > 8, ut = beta(9); vt = beta(10);
else                 ut = 0;       vt = 0;
end

% Environmental height gradient
zxenv = (f/g)*vt; zyenv = -(f/g)*ut;

x = xyt(:,1); y = xyt(:,2); t = xyt(:,3);

r = hypot(x-dx-ut*t, y-dy-vt*t);
nr = length(r);
[z,dzr] = holland_zt([r t], beta(1:6));

z = z + zxenv*x + zyenv*y;

if nargout >= 2
   dz = zeros(nr,9);
   % Derivatives with respect to vm, rm, b, zc, Tbar, dvm2dr
   dz(:,1:6) = dzr(:,1:6);
   % Derivatives with respect to dx, dy, ut, vt
   dz(:,7) = -dzr(:,7) .* (x - dx - ut*t)./r;
   dz(:,8) = -dzr(:,7) .* (y - dy - vt*t)./r;
   dz(:,9) = t .* dz(:,7);
   dz(:,10)= t .* dz(:,8);
end


