function rsm = mrankine_rsm(a)
% function rsm = mrankine_rsm(a)
% Finds the scaled radius rsm = rs(rm) satisfying ws(rsm) = wm, by bisection
% for the modified-Rankine parametric wind profile

vm  = a(1);   % maximum wind
rm  = a(2);   % radius of maximum winds
alp = a(3);   % outer vortex decay exponent   ( v2(r) = vm*(r/rm)^(-alp) )
n1  = a(4);   % Exponent for v1 (inner zone)  ( v1(r) = vm*(r/rm)^n1 )
 % pc = a(5);   % central pressure (not used)
 % RT = 287*a(6);  % for density terms (not used)


% Find wm, the weight that must apply at rm, and its derivatives.
wm = alp/(n1 + alp);

% Find the scaled radius rsm = rs(rm) satisfying ws(rsm) = wm, by bisection
% Here f(rs) = ws(rs) - wm
rs1 = -1; f1 = -wm;
rs2 =  1; f2 = 1 - wm;
for it = 1 : 100
   rsm =  0.5*(rs1 + rs2); 
   fm = (1/256) * (1 + rsm).^5 .* (128 - rsm.*(325 - rsm.*(345 - rsm.*(175 - rsm*35)))) - wm;
   if fm < 0
      rs1 = rsm; f1 = fm;
   elseif fm > 0
      rs2 = rsm; f2 = fm;
   else
      break;
   end
   % Need a tight criterion as this is used in iterative fit
   if rs2 - rs1 < 1e-12 
      break;
   end
end

