function [z,dz] = plprof_z(r,beta)
% function [z,dz] = plprof_z(r,beta)
% Power-law parametric height profile
% beta = [ alpha rscale zc Tbar ]
% dz(:,1:4) is the derivatives of z with respect to beta 
% dz(:,5) is the derivative of z with respect to r

g = 9.80665;

alpha  = beta(1);
rscale = beta(2);
zc     = beta(3);
zg     = beta(4);
RT     = 287*beta(5);

nr = length(r);
z = zeros(nr,1);
if nargout >= 2
   dz = zeros(nr,5);
end

ix = find(r > 0.0);
if ~isempty(ix)
   if 1
      rr = r(ix)/abs(rscale);
      z(ix) = zc + zg*rr.^(2 + alpha^2)./(1 + rr.^2);
      if nargout >= 2
         dz(ix,1) = 2*alpha*zg*log(rr).*rr.^(2 + alpha^2)./(1 + rr.^2);
         dz(ix,2) = -(zg/rscale)*(2 + alpha^2*(1 + rr.^2)).*rr.^(2 + alpha^2)./((1 + rr.^2).^2);
         dz(ix,3) = 1;
         dz(ix,4) = rr.^(2 + alpha^2)./(1 + rr.^2);
         dz(ix,5) = 0.0;
         dz(ix,6) = (zg/abs(rscale))*(2 + alpha^2*(1 + rr.^2)).*rr.^(1 + alpha^2)./((1 + rr.^2).^2);
      end
   else
      rr = (r(ix)/rscale).^2;
      z(ix) = zc + rr.^alpha;
      if nargout >= 2
         dz(ix,1) = log(rr).*(rr.^alpha);
         dz(ix,2) = -(2*alpha/rscale) * rr.^alpha;
         dz(ix,3) = 1;
         dz(ix,4) = 0.0;
         dz(ix,5) = 0.0;
         dz(ix,6) = (2*alpha/rscale^2) * r(ix) .* rr.^(alpha - 1);
      end
   end
end

ix = find(r == 0.0);
if ~isempty(ix)
   z(ix) = zc;
   if nargout >= 2
      dz(ix,1) = 0.0;
      dz(ix,2) = 0.0;
      dz(ix,3) = 1.0;
      dz(ix,4) = nan;
      dz(ix,5) = nan;
      dz(ix,6) = 0.0;
   end
end

% if ~isreal(z)
%    beta
%    pause
% end
