function [b,chisq] = regress_2err(y,x,sigy,sigx)
% function [b,chisq] = regress_2err(y,x,sigy,sigx)
% Univariate linear regression when both x and y have errors 
% After Press et al section 15.3

% Initial guess for slope
stdy = std(y); stdx = std(x);
y1 = (y - mean(y))/stdy;
x1 = (x - mean(x))/stdx;
b1 = regress(y1,[ones(size(x1)),x1]);
b0 = (stdy/stdx)*b1(2);

% Brackets and cost fns
bm = b0 - 1; bp = b0 + 1;
w0 = 1./(sigy.^2 + (b0*sigx).^2); a0 = sum(w0.*(y - b0*x)) / sum(w0);
wm = 1./(sigy.^2 + (bm*sigx).^2); am = sum(wm.*(y - bm*x)) / sum(wm);
wp = 1./(sigy.^2 + (bp*sigx).^2); ap = sum(wp.*(y - bp*x)) / sum(wp);
k0 = sum( w0.*(y - a0 - b0*x).^2 );
km = sum( wm.*(y - am - bm*x).^2 );
kp = sum( wp.*(y - ap - bp*x).^2 );

for it = 1 : 30
   if (kp < k0 | km < k0)
      disp(sprintf('Bracketing failure %.3f %.3f %.3f',km,k0,kp));
      b = nan; chisq = nan;
      return
   end
   if (b0 - bm) > (bp - b0)
      bn = bm*0.38197 + b0*0.61803;
      wn = 1./(sigy.^2 + (bn*sigx).^2); an = sum(wn.*(y - bn*x)) / sum(wn);
      kn = sum( wn.*(y - an - bn*x).^2 );
      if (kn < k0)
         ap = a0; bp = b0; wp = w0; kp = k0;
         a0 = an; b0 = bn; w0 = wn; k0 = kn;
      else
         am = an; bm = bn; wm = wn; km = kn;
      end
   else
      bn = bp*0.38197 + b0*0.61803;
      wn = 1./(sigy.^2 + (bn*sigx).^2); an = sum(wn.*(y - bn*x)) / sum(wn);
      kn = sum( wn.*(y - an - bn*x).^2 );
      if (kn < k0)
         am = a0; bm = b0; wm = w0; km = k0;
         a0 = an; b0 = bn; w0 = wn; k0 = kn;
      else
         ap = an; bp = bn; wp = wn; kp = kn;
      end
   end
   if (bp - b0 < 1e-4)
      b = [am ; bm];
      chisq = km;
      return
   end
  %[km k0 kp kn]
end

b = [nan ; nan]; 
chisq = nan;


