function [uxa, vxa, err] = tcuvsi(xg,yg,uxb,vxb,xo,yo,uxo,vxo,Lrad,nu,sigb,sigo,covtype)
% Does a 2-dimensional bivariate statistical interpolation wind analysis of 
% observations (uxo,vxo) at locations (xo,yo) onto a grid (xg,yg) with background
% field (uxb,vxb). (xg,yg) need to have been made using meshgrid and have constant
% spacing.
% Follows somewhere between Lorenc (1981) and  Talagrand (1997) section 4.
%%%NOTYET Background error covariances are modelled in polar coordinates with 
% length scales Lrad and Laz, and variance sigb^2. Observation errors
% are assumed uncorrelated with variance sigo^2. This turned out to not work!

if isunix
   addpath('/bm/ghome/jdk/assim/matlab/');
else
   addpath('d:/jeff/assim/matlab/');
end

if nargin < 12
   disp('tcuvsi: insufficient arguments');
   uxa = nan; vxa = nan;
   return
elseif nargin == 12
   covtype = 'gauss';
   disp('Using gaussian covariance model');
end

calcB = 0;   % Calculate off-diagonal terms of B

mu = nan; sigz = nan;   % covariance model parameters

sigb2 = sigb^2; sigo2 = sigo^2;

[ny,nx] = size(xg); nxy = nx*ny;
rg = hypot(xg,yg); thg = atan2(yg,xg); 
dx = xg(1,2) - xg(1,1); dy = yg(2,1) - yg(1,1);

ro = hypot(xo, yo); tho = atan2(yo,xo); no = length(xo);

% Put all obs into one vector.
obs = [ uxo ; vxo ];
obsloc = [ xo yo ; xo yo ];
obstype = [ repmat(2,[no,1]) ; repmat(3,[no,1]) ];

% Put all gridpoints into one vector.
gridloc = [ xg(:) yg(:) ; xg(:) yg(:) ];
gridtype = [ repmat(2,[nx*ny,1]) ; repmat(3,[nx*ny,1]) ];

% Interpolate background values to observation points
uxb_o = interp2( xg,yg,uxb, xo,yo ); 
vxb_o = interp2( xg,yg,vxb, xo,yo ); 
bkg_o = [ uxb_o ; vxb_o ];

% Calculate innovation covariance matrix
if strcmpi(covtype, 'gauss')
   C  = cov_mv2(obsloc, obsloc, obstype, obstype, sigb, sigz, Lrad, Lrad, mu, nu, nan);
   HB = cov_mv2(obsloc,gridloc, obstype,gridtype, sigb, sigz, Lrad, Lrad, mu, nu, nan);
elseif strcmpi(covtype, 'SOAR')
   C  = cov_mv2_SOAR(obsloc, obsloc, obstype, obstype, sigb, sigz, Lrad, Lrad, mu, nu, nan);
   HB = cov_mv2_SOAR(obsloc,gridloc, obstype,gridtype, sigb, sigz, Lrad, Lrad, mu, nu, nan);
else
   disp(sprintf('tcuvsi>> ERROR Unknown covariance type %s', covtype));
   uca = nan; vxa = nan;
   return
end

for io = 1 : 2*no
   C(io,io) = C(io,io) + sigo2;
end

anal = HB' * inv(C) * ( obs - bkg_o );  % Analysis increments
uxa = uxb + reshape( anal(      1:  nx*ny), [ny,nx] );  % Analysis
vxa = vxb + reshape( anal(nx*ny+1:2*nx*ny), [ny,nx] );  % Analysis
err = nan;

