function [wa, err] = tcwsi(xg,yg,wb,xo,yo,wo,Lrad,sigb,sigo)
% Does a 2-dimensional univariate statistical interpolation analysis of 
% observations wo at locations (xo,yo) onto a grid (xg,yg) with background
% field wb. (xg,yg) need to have been made using meshgrid and have constant
% spacing.
% Follows somewhere between Lorenc (1981) and  Talagrand (1997) section 4.

if isunix
   addpath('/bm/ghome/jdk/assim/matlab/');
else
   addpath('d:/jeff/assim/matlab/');
end

sigb2 = sigb^2; sigo2 = sigo^2;
mu = nan; nu = nan;

[ny,nx] = size(xg); nxy = nx*ny;
dx = xg(1,2) - xg(1,1); dy = yg(2,1) - yg(1,1);
no = length(wo);

% Put all obs into one vector.
obs = [ wo ];
obsloc = [ xo yo ];
obstype = [ repmat(1,[no,1]) ];

% Put all gridpoints into one vector.
gridloc = [ xg(:) yg(:) ];
gridtype = [ repmat(1,[nx*ny,1]) ];

% Interpolate background values to observation points
wb_o = interp2( xg,yg,wb, xo,yo ); 
bkg_o = [ wb_o ];

if length(wo) >= 1
   % Calculate innovation covariance matrix
   C = cov_mv2(obsloc,obsloc, obstype,obstype, nan, sigb, Lrad, Lrad, mu, nu, nan);
   for io = 1 : no
      C(io,io) = C(io,io) + sigo2;
   end
   HB = cov_mv2(obsloc,gridloc, obstype,gridtype, nan, sigb, Lrad, Lrad, mu, nu, nan);

   anal = HB' * inv(C) * ( obs - bkg_o );  % Analysis increments
   wa = wb + reshape( anal, [ny,nx] );  % Analysis
   err = nan;
else
   disp('tcwsi WARNING>> no observations');
   wa = wb;
   err = nan;
end

