% 
clear
a = [50 40e3 1.3 95000 298]';
dr = 2e2;
f = cor(15);
r = [0:dr:100e3]';
[v,dv] = holland_v(r,a,f);
fig(1); clf;
subplot(2,2,1); cla; plot(r/1e3,v/1e2);
subplot(2,2,2); cla; plot(r/1e3,dv(:,1));
subplot(2,2,3); cla; plot(r/1e3,dv(:,2));
subplot(2,2,4); cla; plot(r/1e3,dv(:,3));

% Check derivatives
clear;
global f0;
a = [30 30e3 1.3 95000 298]';
r = [ 80e3 ];
f = cor(15);
f0 = f;
for ii = 1 : 4
   del = 1e-06; 
   a1 = a; a1(ii) = a1(ii)*(1 + del);
   [v1,dv1] = holland_v(r,a1,f);
   a0 = a; a0(ii) = a0(ii)*(1 - del);
   [v0,dv0] = holland_v(r,a0,f);
   [v2,dv2] = holland_v(r,a,f);
   disp(sprintf('%12.4g %12.4g',(v1 - v0)/(a1(ii) - a0(ii)), dv2(:,ii)));
end
del = 1e-06; 
r1 = r*(1 + del);
[v1,dv1] = holland_v(r1,a,f);
r0 = r*(1 - del);
[v0,dv0] = holland_v(r0,a,f);
[v2,dv2] = holland_v(r,a,f);
[ (v1 - v0)/(r1 - r0)  dv2(:,5) ]

% Check derivatives for vaz_xyuv.m
clear;
a = [ 0 0 0 0 0 1e3 -9e3 5 -3 ]';
uv = [ 40 -30 ]; xyt = [ 10e3 40e3 4 ];
for ii = 6 : 9
   del = 1e-06;
   a1 = a; a1(ii) = a1(ii)*(1 + del);
   [v1,dv1] = vaz_xyuv(uv, xyt, a1);
   a0 = a; a0(ii) = a0(ii)*(1 - del);
   [v0,dv0] = vaz_xyuv(uv, xyt, a0);
   [v2,dv2] = vaz_xyuv(uv, xyt, a);
   disp(sprintf('%12.4g %12.4g',(v1 - v0)/(a1(ii) - a0(ii)), dv2(:,ii)));
end

% Test mrqmin fitting
clear;
aa = [50,25e3,1.3,95000,298]'; na = length(aa);
ia = [ 1,   1,  1,    0,  0]';
dp = 1e-2*aa(1)^2*1.15*2.718/aa(3);
f = cor(15); 
r = 1e3*[1 3 20:1:30  80:4:100]'; nr = length(r);
%r = 1e3*[1 3 20:1:30  80:4:100 200:100:1000]'; nr = length(r);
sig = 3*ones(nr,1); 
rfit = 1e3*[1 : 120]'; drfit = rfit(2) - rfit(1);
vtrue = holland_v(rfit,aa,f);
ptrue = holland_p(rfit,aa);

nmc = 100;
amc = zeros(nmc,na);
chisq = zeros(nmc,1);
vomc = zeros(nmc,nr);
doplot = (nmc == 1);
for ii = 1 : nmc
   vo = holland_v(r,aa,f) + sig.*randn(nr,1);
   vomc(ii,:) = vo';
   a0 = aa;
   
   % Fudge to keep length scale  and rm under control
   if 1
      r1 = [ r ; -999.0 ]; vo1 = [ vo ; 0 ]; sig1 = [ sig ; 1 ];
   else
      r1 = r; vo1 = vo; sig1 = sig;
   end
   [a,cov,chisq(ii)] = mrqmin(r1, vo1, sig1, a0, ia, 'holland_v', 100, 10);

   amc(ii,:) = a';
   
   vfit = holland_v(rfit,amc(ii,:)',f);
   pfit = holland_p(rfit,[amc(ii,:)' ; 95000]);
   
   if doplot
      fig(1); clf;
      subplot(3,1,1); cla;
      plot(r/1e3,vomc(ii,:),'bo'); hold on; xlim(0,120); 
      plot(rfit/1e3,vfit,'r');
      plot(rfit/1e3,vtrue,'g-');
      subplot(3,1,2); cla;
      plot(rfit/1e3,(vfit-vtrue),'r'); hold on; xlim(0,120);
      subplot(3,1,3); cla;
      plot(rfit/1e3,pfit/1e2,'r'); hold on; xlim(0,120); 
      plot(rfit/1e3,ptrue/1e2,'g-');     
      reltext(0.5,0.8,sprintf('dp true=%.1f fit=%.1f hPa', ...
         dp,1e-2*amc(ii,1)^2*1.15*2.718/amc(ii,3)));
   end
end

%save test_holland_v
dpfit = 1e-2*1.15*2.718*amc(:,1).^2./amc(:,3);
bara = mean(amc); siga = std(amc);
astats = [ bara-siga ; bara ; bara+siga ];
bardp = mean(dpfit); sigdp = std(dpfit);
dpstats = [ bardp-sigdp; bardp ; bardp+sigdp ];

fig(2); clf;
subplot(2,2,1); cla;
plot(amc(:,1),chisq,'o', astats(:,1),[0 0 0],'r*'); 
xlabel('vm'); vline(aa(1)); ylabel('\chi^2');
subplot(2,2,2); cla;
plot(amc(:,2)/1e3,chisq,'o', astats(:,2)/1e3,[0 0 0],'r*'); 
vline(aa(2)/1e3); xlabel('rm'); 
subplot(2,2,3); cla;
plot(amc(:,3),chisq,'o', astats(:,3),[0 0 0],'r*'); 
vline(aa(3)); xlabel('b'); ylabel('\chi^2');
subplot(2,2,4); cla;
plot(dpfit,chisq,'o', dpstats,[0 0 0],'r*'); 
vline(dp); xlabel('dp'); 

% Test mrqmin fitting for cartesian wind data with relocation.

clear;
aa = [50,25e3,1.3,95000,298,0,0]'; na = length(aa);
ia = [ 1,   1,  1,    0,  0,1,1]';
ja = [ 1,   1,  1,    0,  0,0,0]';
dp = 1e-2*aa(1)^2*1.15*2.718/aa(3);
global f0;
f = cor(15); f0 = f; 
r = 1e3*[1 3 20:1:30  80:4:100]'; nr = length(r);
lam = 2*pi*rand(nr,1);
x = r.*cos(lam); y = r.*sin(lam); xy = [ x, y ];
sig = 2*ones(nr,1); 
rfit = 1e3*[1 : 120]'; drfit = rfit(2) - rfit(1);
vtrue = holland_v(rfit,aa,f);
vobs  = holland_v(r,   aa,f);
uxobs = -vobs.*sin(lam); vxobs = vobs.*cos(lam);
ptrue = holland_p(rfit,aa);

nmc = 100; ii = 1;
amc = zeros(nmc,na);
chisq = zeros(nmc,1);
vomc = zeros(nmc,nr);
doplot = (nmc == 1);
for ii = 1 : nmc
   uvo = [ uxobs + sig.*randn(nr,1), vxobs + sig.*randn(nr,1) ];
   vomc(ii,:) = vaz( uvo, xy, aa )';
   a0 = aa;
   
   [a,cov,chisq(ii)] = mrqmin_proj(xy, uvo, sig, a0, ia, ...
         @holland_v_xy, @vaz_xy, 100, 10);
 % [a2,cov,chisq2  ] = mrqmin_proj(xy, uvo, sig, a0, ja, ...
 %       @holland_v_xy, @vaz_xy, 100, 10);
 % [a3,cov,chisq3] = mrqmin(r, vomc(ii,:)', sig, a0, ja, ...
 %       @holland_v, 100, 10);

   amc(ii,:) = a';
   
   vfit = holland_v(rfit,amc(ii,:)',f);
   pfit = holland_p(rfit,amc(ii,:)');
   
   if doplot
      fig(1); clf;
      subplot(3,1,1); cla;
      plot(r/1e3,vomc(ii,:),'bo'); hold on; xlim(0,120); 
      plot(rfit/1e3,vfit,'r');
      plot(rfit/1e3,vtrue,'g-');
      subplot(3,1,2); cla;
      plot(rfit/1e3,(vfit-vtrue),'r'); hold on; xlim(0,120);
      subplot(3,1,3); cla;
      plot(rfit/1e3,pfit/1e2,'r'); hold on; xlim(0,120); 
      plot(rfit/1e3,ptrue/1e2,'g-');     
      reltext(0.5,0.8,sprintf('dp true=%.1f fit=%.1f hPa', ...
         dp,1e-2*amc(ii,1)^2*1.15*2.718/amc(ii,3)));
   end
end

%save test_holland_v
dpfit = 1e-2*1.15*2.718*amc(:,1).^2./amc(:,3);
bara = mean(amc); siga = std(amc);
astats = [ bara-siga ; bara ; bara+siga ];
bardp = mean(dpfit); sigdp = std(dpfit);
dpstats = [ bardp-sigdp; bardp ; bardp+sigdp ];

fig(2); clf;
subplot(2,3,1); cla;
plot(amc(:,1),chisq,'o', astats(:,1),[0 0 0],'r*'); 
xlabel('vm'); vline(aa(1)); ylabel('\chi^2');
subplot(2,3,2); cla;
plot(amc(:,2)/1e3,chisq,'o', astats(:,2)/1e3,[0 0 0],'r*'); 
vline(aa(2)/1e3); xlabel('rm'); 
subplot(2,3,3); cla;
plot(amc(:,3),chisq,'o', astats(:,3),[0 0 0],'r*'); 
vline(aa(3)); xlabel('b'); i
subplot(2,3,4); cla;
plot(amc(:,6)/1e3,chisq,'o', astats(:,6)/1e3,[0 0 0],'r*'); 
vline(0); xlabel('dx'); ylabel('\chi^2');
subplot(2,3,5); cla;
plot(amc(:,7)/1e3,chisq,'o', astats(:,7)/1e3,[0 0 0],'r*'); 
vline(0); xlabel('dx'); 
subplot(2,3,6); cla;
plot(dpfit,chisq,'o', dpstats,[0 0 0],'r*');
vline(dp); xlabel('dp'); 


% Test mrqmin fitting for cartesian wind data with relocation and motion.

clear;
ut = 5; vt = 3;
aa = [50,25e3,1.3,95000,298,0,0,ut,vt]'; na = length(aa);
ia = [ 1,   1,  1,    0,  0,1,1,1, 1 ]';
ja = [ 1,   1,  1,    0,  0,0,0,0, 0 ]';
dp = 1e-2*aa(1)^2*1.15*2.718/aa(3);
global f0;
f = cor(15); f0 = f; 
r = 1e3*[1 3 20:1:30  80:4:100]'; nr = length(r);
lam = 2*pi*rand(nr,1);
t = 1e4*rand(nr,1);
x = r.*cos(lam) + ut*t; y = r.*sin(lam) + vt*t; 
xyt = [ x, y, t ];
sig = 2*ones(nr,1); 
rfit = 1e3*[1 : 120]'; drfit = rfit(2) - rfit(1);
vtrue = holland_v(rfit,aa,f);
vobs  = holland_v(r,   aa,f);
uxobs = -vobs.*sin(lam) + ut; vxobs = vobs.*cos(lam) + vt;
ptrue = holland_p(rfit,aa);

nmc = 100; ii = 1;
amc = zeros(nmc,na);
chisq = zeros(nmc,1);
vomc = zeros(nmc,nr);
doplot = (nmc == 1);
for ii = 1 : nmc
   uvo = [ uxobs + sig.*randn(nr,1), vxobs + sig.*randn(nr,1) ];
   vomc(ii,:) = vaz_xyuv( uvo, xyt, aa )';
   a0 = aa;
   
   [a,cov,chisq(ii)] = mrqmin_proj(xyt, uvo, sig, a0, ia, ...
         @holland_v_xyuv, @vaz_xyuv, 100, 10);

   amc(ii,:) = a';
   
   vfit = holland_v(rfit,amc(ii,:)',f);
   pfit = holland_p(rfit,amc(ii,:)');
   
   if doplot
      fig(1); clf;
      subplot(3,1,1); cla;
      plot(r/1e3,vomc(ii,:),'bo'); hold on; xlim(0,120); 
      plot(rfit/1e3,vfit,'r');
      plot(rfit/1e3,vtrue,'g-');
      subplot(3,1,2); cla;
      plot(rfit/1e3,(vfit-vtrue),'r'); hold on; xlim(0,120);
      subplot(3,1,3); cla;
      plot(rfit/1e3,pfit/1e2,'r'); hold on; xlim(0,120); 
      plot(rfit/1e3,ptrue/1e2,'g-');     
      reltext(0.5,0.8,sprintf('dp true=%.1f fit=%.1f hPa', ...
         dp,1e-2*amc(ii,1)^2*1.15*2.718/amc(ii,3)));
   end
end

%save test_holland_v
dpfit = 1e-2*1.15*2.718*amc(:,1).^2./amc(:,3);
bara = mean(amc); siga = std(amc);
astats = [ bara-siga ; bara ; bara+siga ];
bardp = mean(dpfit); sigdp = std(dpfit);
dpstats = [ bardp-sigdp; bardp ; bardp+sigdp ];

fig(2); clf;
subplot(2,4,1); cla;
plot(amc(:,1),chisq,'o', astats(:,1),[0 0 0],'r*'); 
xlabel('vm'); vline(aa(1)); ylabel('\chi^2');
subplot(2,4,2); cla;
plot(amc(:,2)/1e3,chisq,'o', astats(:,2)/1e3,[0 0 0],'r*'); 
vline(aa(2)/1e3); xlabel('rm'); 
subplot(2,4,3); cla;
plot(amc(:,3),chisq,'o', astats(:,3),[0 0 0],'r*'); 
vline(aa(3)); xlabel('b'); i
subplot(2,4,4); cla;
plot(dpfit,chisq,'o', dpstats,[0 0 0],'r*');
vline(dp); xlabel('dp'); 
subplot(2,4,5); cla;
plot(amc(:,6)/1e3,chisq,'o', astats(:,6)/1e3,[0 0 0],'r*'); 
vline(0); xlabel('dx'); ylabel('\chi^2');
subplot(2,4,6); cla;
plot(amc(:,7)/1e3,chisq,'o', astats(:,7)/1e3,[0 0 0],'r*'); 
vline(0); xlabel('dy'); 
subplot(2,4,7); cla;
plot(amc(:,8),chisq,'o', astats(:,8),[0 0 0],'r*'); 
vline(ut); xlabel('ut'); 
subplot(2,4,8); cla;
plot(amc(:,9),chisq,'o', astats(:,9),[0 0 0],'r*'); 
vline(vt); xlabel('vt');





