function [vc,dvc] = vaz_xyuv(uv, xyt, a)
% function [vc,dvc] = vaz_xyuv(uv, xyt, a)
% Used with mrqmin_proj to fit analytical profiles to wind data.
% Returns the azimuthal wind component about the point (0,0) for wind 
% vectors uv(ii,:) at points xyt(ii,:). 

dx = a(6); dy = a(7); ut = a(8); vt = a(9);

xdx = xyt(:,1) - dx - ut*xyt(:,3); 
ydy = xyt(:,2) - dy - vt*xyt(:,3);
t   = xyt(:,3);
r = hypot(xdx, ydy);

% Cartesian storm-relative wind components
ux = uv(:,1) - ut; vx = uv(:,2) - vt;  

% Project into cylindrical coordinates
vc = (-ux.*ydy + vx.*xdx)./r;  

if nargout >= 2
   dvc = zeros( size(uv,1), 9 );
   dvc(:,6) = vc.*xdx./r.^2 - vx./r;
   dvc(:,7) = vc.*ydy./r.^2 + ux./r;
   dvc(:,8) = t.*dvc(:,6) + ydy./r;
   dvc(:,9) = t.*dvc(:,7) - xdx./r;
end

