function rsm = willoughby2_rsm(a)
% function rsm = willoughby2_rsm(a)
% Finds the scaled radius rsm = rs(rm) satisfying ws(rsm) = wm, by bisection
% for the double-exponential parametric wind profile of Willoughby (2002)

A  = a(1);   % amplitude of first exponential
L1 = a(2);   % length scale of first exponential
B  = a(3);   % amplitude of second exponential
L2 = a(4);   % length scale of second exponential
rm = a(5);   % radius of maximum winds
n1 = a(6);   % Exponent for v1 (inner zone)
 % pc = a(7);   % central pressure (not used)
 % RT = 287*a(8);  % for density terms (not used)


% Find wm, the weight that must apply at rm, and its derivatives.
wm = (A + B)*L1*L2*n1 / (A*L2*(L1*n1 + rm) + B*L1*(L2*n1 + rm));

% Find the scaled radius rsm = rs(rm) satisfying ws(rsm) = wm, by bisection
% Here f(rs) = ws(rs) - wm
rs1 = -1; f1 = -wm;
rs2 =  1; f2 = 1 - wm;
for it = 1 : 100
   rsm =  0.5*(rs1 + rs2); 
%% Old version has 2 continuous derivatives, new one has 4. See also dwsdrs_rs
 % fm = 0.5 + 0.0625*rsm.*(3*rsm.^4 - 10*rsm.^2 + 15) - wm;
   fm = (1/256) * (1 + rsm).^5 .* (128 - rsm.*(325 - rsm.*(345 - rsm.*(175 - rsm*35)))) - wm;
   if fm < 0
      rs1 = rsm; f1 = fm;
   elseif fm > 0
      rs2 = rsm; f2 = fm;
   else
      break;
   end
   % Need a tight criterion as this is used in iterative fit
   if rs2 - rs1 < 1e-12 
      break;
   end
end

